A functional Clojure wrapper for the modern Java MongoDB API.
A functional Clojure wrapper for the modern Java MongoDB API.
Type conversions between Clojure and MongoDB.
Type conversions between Clojure and MongoDB.
Upload and download files, query by metadata.
Upload and download files, query by metadata.
Functions for defining a collection schema.
Functions for defining a collection schema.
Convenience functions for automating certain tasks.
Convenience functions for automating certain tasks.
Add call-back functions for listening to query events.
Add call-back functions for listening to query events.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |