Type conversions between Clojure and MongoDB.
Type conversions between Clojure and MongoDB.
(clj->mongo v)Convert types from Clojure to MongoDB.
Convert types from Clojure to MongoDB.
(list->map v)Convert a list of keywords to keys with value 1 in BSON document.
Convert a list of keywords to keys with value 1 in BSON document.
(mongo->clj v)Convert types from MongoDB to Clojure.
Convert types from MongoDB to Clojure.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |