A functional Clojure wrapper for the modern Java MongoDB API.
A functional Clojure wrapper for the modern Java MongoDB API.
Pad payload before sending to database.
Pad payload before sending to database.
Functions for defining a collection schema.
Functions for defining a collection schema.
Convenience functions for automating certain tasks.
Convenience functions for automating certain tasks.
Add call-back functions for listening to query events.
Add call-back functions for listening to query events.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |